.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

**********************************
 PDF version of the PyMVPA Manual
**********************************

The PDF version of the manual is available for download_.

.. _download: PyMVPA-Manual.pdf


.. toctree::
   :maxdepth: 3

   intro
   installation
   overview
   tutorial
   misc
   examples
   faq
   glossary
   references
   legal
   changelog
